==> global-0.0.29.tar.gz: lib/src/routes/GWebViewRoute.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GWebViewRoute extends StatefulWidget {
  Map<String, dynamic> _arguments;

  GWebViewRoute(this._arguments, {super.key});
}

abstract class _GWebViewRouteState<T extends GWebViewRoute>
    extends State<GWebViewRoute> {
  late String pageTitle;
  late InAppWebViewController webviewController;
  bool _progDialogShowing = false;
  late InAppWebView webView;

  @override
  void initState() {
    super.initState();
    Uri? initialUri = Uri.tryParse(widget._arguments[GKeys.initialWebviewData]);
    pageTitle = GTexts.untitled;
    webView = InAppWebView(
      initialData: initialUri == null
          ? InAppWebViewInitialData(
              data: widget._arguments[GKeys.initialWebviewData])
          : null,
      initialUrlRequest: initialUri == null
          ? null
          : () {
              /*1. Delay put as progress dialog was getting pushed during build
                2. Progress dialog push handling being done here, so that user doesn't feel
                   that screen is unresponsive for long, after entering webview*/
              Future.delayed(
                  const Duration(milliseconds: 200), _showProgDialogHandler);
              return URLRequest(url: WebUri.uri(initialUri));
            }(),
      initialOptions: InAppWebViewGroupOptions(
        crossPlatform: InAppWebViewOptions(
          useShouldOverrideUrlLoading: true,
          useOnDownloadStart: true,
        ),
        android: AndroidInAppWebViewOptions(useHybridComposition: true),
        ios: IOSInAppWebViewOptions(allowsInlineMediaPlayback: true),
      ),
      onWebViewCreated: (controller) {
        webviewController = controller;
        widget._arguments[GKeys.webviewController] = webviewController;
      },
      shouldOverrideUrlLoading: (controller, navigationAction) async {
        var uri = navigationAction.request.url!;
        if (!GUtils.whiteListedSchemesForWV.contains(uri.scheme)) {
          if (await canLaunchUrl(uri)) {
            await launchUrl(uri);
            return NavigationActionPolicy.CANCEL;
          }
        }
        if (navigationAction.isForMainFrame) {
          /*Progress dialog push handling being done here, so that user doesn't feel
          that screen is unresponsive for long, after link click*/
          _showProgDialogHandler();
        }
        return NavigationActionPolicy.ALLOW;
      },
      onTitleChanged: (controller, title) {
        if (title != null && title.isNotEmpty) {
          setState(() => pageTitle = title);
        }
      },
      onLoadStart: (_, __) {
        _showProgDialogHandler();
      },
      onLoadStop: (controller, __) {
        _hideProgDialogHandler();
      },
      onLoadError: (_, __, ___, ____) {
        _hideProgDialogHandler();
      },
      onDownloadStartRequest: (_, downloadStartReq) {
        /*Progress dialog pop handling being done here, because for a download URL in iOS,
        [onLoadError] gets called after [onDownloadStartRequest]
        and [onLoadStop] never gets called, which hangs the app*/
        _hideProgDialogHandler();
      },
    );
  }

  _showProgDialogHandler() {
    if (!_progDialogShowing) {
      GUtils.showProgressDialog();
      _progDialogShowing = true;
    }
  }

  _hideProgDialogHandler() {
    Future.delayed(
      const Duration(milliseconds: 200),
      () {
        if (_progDialogShowing) {
          Navigator.pop(context);
          _progDialogShowing = false;
        }
      },
    );
  }
}

==> global-0.0.30.tar.gz: lib/src/routes/GWebViewRoute.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GWebViewRoute extends StatefulWidget {
  Map<String, dynamic> arguments;

  GWebViewRoute(this.arguments, {super.key});
}

abstract class GWebViewRouteState<T extends GWebViewRoute>
    extends State<GWebViewRoute> {
  late String pageTitle;
  late InAppWebViewController webviewController;
  bool _progDialogShowing = false;
  late InAppWebView webView;

  @override
  void initState() {
    super.initState();
    Uri? initialUri = Uri.tryParse(widget.arguments[GKeys.initialWebviewData]);
    pageTitle = GTexts.untitled;
    webView = InAppWebView(
      initialData: initialUri == null
          ? InAppWebViewInitialData(
              data: widget.arguments[GKeys.initialWebviewData])
          : null,
      initialUrlRequest: initialUri == null
          ? null
          : () {
              /*1. Delay put as progress dialog was getting pushed during build
                2. Progress dialog push handling being done here, so that user doesn't feel
                   that screen is unresponsive for long, after entering webview*/
              Future.delayed(
                  const Duration(milliseconds: 200), _showProgDialogHandler);
              return URLRequest(url: WebUri.uri(initialUri));
            }(),
      initialOptions: InAppWebViewGroupOptions(
        crossPlatform: InAppWebViewOptions(
          useShouldOverrideUrlLoading: true,
          useOnDownloadStart: true,
        ),
        android: AndroidInAppWebViewOptions(useHybridComposition: true),
        ios: IOSInAppWebViewOptions(allowsInlineMediaPlayback: true),
      ),
      onWebViewCreated: (controller) {
        webviewController = controller;
        widget.arguments[GKeys.webviewController] = webviewController;
      },
      shouldOverrideUrlLoading: (controller, navigationAction) async {
        var uri = navigationAction.request.url!;
        if (!GUtils.whiteListedSchemesForWV.contains(uri.scheme)) {
          if (await canLaunchUrl(uri)) {
            await launchUrl(uri);
            return NavigationActionPolicy.CANCEL;
          }
        }
        if (navigationAction.isForMainFrame) {
          /*Progress dialog push handling being done here, so that user doesn't feel
          that screen is unresponsive for long, after link click*/
          _showProgDialogHandler();
        }
        return NavigationActionPolicy.ALLOW;
      },
      onTitleChanged: (controller, title) {
        if (title != null && title.isNotEmpty) {
          setState(() => pageTitle = title);
        }
      },
      onLoadStart: (_, __) {
        _showProgDialogHandler();
      },
      onLoadStop: (controller, __) {
        _hideProgDialogHandler();
      },
      onLoadError: (_, __, ___, ____) {
        _hideProgDialogHandler();
      },
      onDownloadStartRequest: (_, downloadStartReq) {
        /*Progress dialog pop handling being done here, because for a download URL in iOS,
        [onLoadError] gets called after [onDownloadStartRequest]
        and [onLoadStop] never gets called, which hangs the app*/
        _hideProgDialogHandler();
      },
    );
  }

  _showProgDialogHandler() {
    if (!_progDialogShowing) {
      GUtils.showProgressDialog();
      _progDialogShowing = true;
    }
  }

  _hideProgDialogHandler() {
    Future.delayed(
      const Duration(milliseconds: 200),
      () {
        if (_progDialogShowing) {
          Navigator.pop(context);
          _progDialogShowing = false;
        }
      },
    );
  }
}
